# -*- coding: utf-8 -*-
from setuphelpers import *
from setupdevhelpers import *
import glob
import waptlicences


def update_package():
    # Declaring local variables
    package_updated = False
    proxies = get_proxies()
    if not proxies:
        proxies = get_proxies_from_wapt_console()
    app_name = control.name

    url_base = "https://www.elastic.co/downloads/beats/winlogbeat"
    json_data = bs_find(url_base,"script", "id", "__NEXT_DATA__",proxies=proxies).text
    all_versions = [i for i in json.loads(json_data)['props']['pageProps']['productVersions'][0] if not i['release_candidate']]
    latest_release = max(all_versions, key=lambda x: Version(x['version_number']))

    download_dict = {
        "windows-x64": "windows-x86_64.msi"
    }
    
    os_type = control.target_os + "-" + ensure_list(control.architecture)[0]
    
    download_url = next(iter([i['url'] for i in latest_release['package'] if i['url'].endswith(download_dict[os_type])]))
    version = latest_release['version_number']
    latest_bin = download_url.rsplit("/", 1)[-1]
    latest_bin_extension = latest_bin.rsplit('.', 1)[-1]

    # Downloading latest binaries
    print(f"Latest {app_name} version is: {version}")
    print(f"Download URL is: {download_url}")
    if not isfile(latest_bin):
        print(f"Downloading: {latest_bin}")
        wget(download_url, latest_bin, proxies=proxies)
    else:
        print(f"Binary is present: {latest_bin}")

    expected_issuer = "Elasticsearch, Inc."
    sign_name = waptlicences.check_msi_signature(latest_bin)[0]
    if sign_name != expected_issuer:
        error(f'Bad issuer {sign_name} != {expected_issuer} ')

    # Changing version of the package
    if Version(version) > Version(control.get_software_version()):
        print(f"Software version updated (from: {control.get_software_version()} to: {Version(version)})")
        package_updated = True
    else:
        print(f"Software version up-to-date ({Version(version)})")

    for f in glob.glob(f'*.{latest_bin_extension}'):
        if f != latest_bin:
            remove_file(f)

    control.set_software_version(version)
    control.save_control_to_wapt()

    return package_updated